==> solid-5.4.0.zip: solid-5.4.0/src/tools/solid-power/solid-power.cpp <==
/*
    Copyright 2014 Alejandro Fiestas Olivares <afiestas@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "solid-power.h"

#include <solid/power.h>
#include <solid/acpluggedjob.h>

#include <QDebug>
#include <QCoreApplication>
#include <QTextStream>

using namespace Solid;
using namespace std;

static QTextStream sCout(stdout);

SolidPower::SolidPower(QObject* parent) : QObject(parent)
{
}

void SolidPower::show()
{
    auto job = Solid::Power::isAcPlugged(this);
    job->exec();

    QString status = job->isPlugged() ? "yes" : "no";

    sCout << "is AC plugged:\t" << status << endl;
}

void SolidPower::listen()
{
    auto power = Power::self();

    connect(power, &Power::acPluggedChanged, [](bool plugged){
        QTextStream lOut(stdout);
        QString status = plugged ? "yes" : "no";
        lOut << "\tAC plugged changed:\t" << status << endl;
    });
}

==> solid-5.65.0.zip: solid-5.65.0/src/tools/solid-power/solid-power.cpp <==
/*
    Copyright 2014 Alejandro Fiestas Olivares <afiestas@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "solid-power.h"

#include <solid/power.h>
#include <solid/acpluggedjob.h>

#include <QTextStream>

using namespace Solid;
using namespace std;

static QTextStream sCout(stdout);

SolidPower::SolidPower(QObject* parent) : QObject(parent)
{
}

void SolidPower::show()
{
    auto job = Solid::Power::isAcPlugged(this);
    job->exec();

    QString status = job->isPlugged() ? "yes" : "no";

    sCout << "is AC plugged:\t" << status << endl;
}

void SolidPower::listen()
{
    auto power = Power::self();

    connect(power, &Power::acPluggedChanged, [](bool plugged){
        QTextStream lOut(stdout);
        QString status = plugged ? "yes" : "no";
        lOut << "\tAC plugged changed:\t" << status << endl;
    });

    connect(power, &Power::aboutToSuspend, [](){
        QTextStream lOut(stdout);
        lOut << "\tAbout to suspend" << endl;
    });

    connect(power, &Power::resumeFromSuspend, [](){
        QTextStream lOut(stdout);
        lOut << "\tResume from suspend" << endl;
    });
}
